HoloToolkit Utilities                        {#mainpage}
============

## Description

When placing holograms in the physical world it is often desirable to go beyond spatial mapping’s mesh and surface planes. When placement is done procedurally, a higher level of environmental understanding is desirable. This usually requires making decisions about what is floor, ceiling, and walls. In addition, the ability to optimize against a set of placement constraints to determining the most desirable physical locations for holographic objects.

During the development of Young Conker and Fragments, Asobo Studios faced this problem head on, developing a room solver for this purpose. Each of these games had game specific needs, but they shared core spatial understanding technology. 

The HoloToolkit.SpatialUnderstanding library encapsulates this technology, allowing you to quickly find empty spaces on the walls, place objects on the ceiling, identify placed for character to sit, and a myriad of other spatial understanding queries. 

All of the source code is included, allowing you to customize it to your needs and share your improvements with the community. The code for the C++ solver has been wrapped into a UWP dll and exposed to Unity with a drop in prefab contained within the HoloToolkit.

## Prefabs

### SpatialUnderstanding

Prefab which implements the spatial understanding scanning flow and provides an interface to the understanding APIs.

## Scripts

### SpatialUnderstanding.cs
Manages the scanning flow, calling the following functions.

- SpatialUnderstanding_Init – Called once at the start.
- GeneratePlayspace_InitScan – Indicates that the scan phase should begin.
- GeneratePlayspace_UpdateScan_DynamicScan – Called each frame to update the scanning process. The camera position and orientation is passed in and is used for the play space painting process, described above. 
- GeneratePlayspace_RequestFinish – Called to finalize the play space. This will use the areas “painted” during the scan phase to define and lock the play space. The application can query statistics during the scanning phase as well as query the custom mesh for providing user feedback. 
- Import_UnderstandingMesh – During scanning, the “SpatialUnderstandingCustomMesh” behavior provided by the module and placed on the understanding prefab will periodically query the custom mesh generated by the process. In addition, this is done once more after scanning has been finalized.

The scanning flow, driven by the “SpatialUnderstanding” behavior calls InitScan, then UpdateScan each frame. When the statistics query reports reasonable coverage, the user is allowed to airtap to call RequestFinish to indicate the end of the scanning phase. UpdateScan continues to be called until it’s return value indicates that the dll has completed processing. 

### SpatialUnderstandingCustomMesh.cs
Contains the custom mesh generated by the understanding dll. It will periodically query the custom mesh generated by the process. In addition, this is done once more after scanning has been finalized.

### SpatialUnderstandingDll.cs
Contains the flow interface to the dll. In addition it contains data structures used by the interface and helper marshalling functions.

### SpatialUnderstandingDllObjectPlacement.cs
Static class containing the object placement API.

### SpatialUnderstandingDllShapes.cs
Static class containing the shape matching API.

### SpatialUnderstandingDllTopology.cs
Static class containing the topology query API.

### SpatialUnderstandingSourceMesh.cs
Behavior responsible for providing the spatial mapping mesh to the dll during the scanning phase.

## Shaders

### SpatialMappingSurface.shader
Shader which can be used to visualize the spatial mapping mesh.

### SpatialUnderstandingSurface.shader
Shader which can be used to visualize the custom spatial understanding mesh.
